@@ -21,7 +21,7 @@ sub ProcessKodakPatch($$$);
 sub WriteUnknownOrPreview($$$);
 sub FixLeicaBase($$;$);
 
-$VERSION = '2.08';
+$VERSION = '2.09';
 
 my $debug;          # set to 1 to enable debugging code
 
@@ -32,7 +32,7 @@ my $debug;          # set to 1 to enable debugging code
 #   write maker notes into a file with different byte ordering!
 # - Put these in alphabetical order to make TagNames documentation nicer.
 @Image::ExifTool::MakerNotes::Main = (
-    # decide which MakerNotes to use (based on camera make/model)
+    # decide which MakerNotes to use (based on makernote header and camera make/model)
     {
         Name => 'MakerNoteApple',
         Condition => '$$valPt =~ /^Apple iOS\0/',
@@ -971,7 +971,7 @@ my $debug;          # set to 1 to enable debugging code
     {
         Name => 'MakerNoteSigma',
         # (starts with "SIGMA\0")
-        Condition => '$$self{Make}=~/^(SIGMA|FOVEON)/',
+        Condition => '$$self{Make}=~/^(SIGMA|FOVEON)/ and $$valPt!~/^SIGMA\0\0\0\0\x03/',
         SubDirectory => {
             TagTable => 'Image::ExifTool::Sigma::Main',
             Validate => '$val =~ /^(SIGMA|FOVEON)/',
@@ -979,6 +979,16 @@ my $debug;          # set to 1 to enable debugging code
             ByteOrder => 'Unknown',
         },
     },
+    {
+        Name => 'MakerNoteSigma3',
+        # (starts with "SIGMA\0\0\0\0\x03")
+        Condition => '$$valPt=~/^SIGMA\0\0\0\0\x03/ and $$self{MakerNoteSigma3}=1',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Sigma::Main',
+            Start => '$valuePtr + 10',
+            ByteOrder => 'Unknown',
+        },
+    },
     {
         Name => 'MakerNoteSony',
         # (starts with "SONY DSC \0" or "SONY CAM \0")
