@@ -23,7 +23,7 @@ $VERSION = '1.08';
         Tags extracted from Mac OS resource files and DFONT files.  These tags may
         also be extracted from the resource fork of any file in OS X, either by
         adding "/..namedfork/rsrc" to the filename to process the resource fork
-        alone, or by using the ExtractEmbedded (-ee) option to process the resource
+        alone, or by using the L<ExtractEmbedded|../ExifTool.html#ExtractEmbedded> (-ee) option to process the resource
         fork as a sub-document of the main file.  When writing, ExifTool preserves
         the Mac OS resource fork by default, but it may deleted with C<-rsrc:all=>
         on the command line.
@@ -219,7 +219,7 @@ resource files.
 
 =head1 AUTHOR
 
-Copyright 2003-2017, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
