@@ -7,9 +7,9 @@
 #
 # Notes:        My apologies for the convoluted logic contained herein, but it
 #               is done this way to retro-fit the Validate feature into the
-#               existing ExifTool code while avoiding the possibility of
-#               introducing potential bugs or slowing down processing when the
-#               Validate feature is not used.
+#               existing ExifTool code while reducing the possibility of
+#               introducing bugs or slowing down processing when this feature
+#               is not used.
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Validate;
@@ -17,7 +17,7 @@ package Image::ExifTool::Validate;
 use strict;
 use vars qw($VERSION %exifSpec);
 
-$VERSION = '1.10';
+$VERSION = '1.14';
 
 use Image::ExifTool qw(:Utils);
 use Image::ExifTool::Exif;
@@ -253,10 +253,10 @@ my %validateInfo = (
     Groups => { 0 => 'ExifTool', 1 => 'ExifTool', 2 => 'ExifTool' },
     Notes => q{
         generated only if specifically requested.  Requesting this tag automatically
-        enables the L<API Validate option|../ExifTool.html#Validate>, imposing
+        enables the API L<Validate|../ExifTool.html#Validate> option, imposing
         additional validation checks when extracting metadata.  Returns the number
         of errors, warnings and minor warnings encountered.  Note that the Validate
-        feature focuses mainly on validation of TIFF/EXIF metadata and files
+        feature focuses mainly on validation of TIFF/EXIF metadata
     },
     PrintConv => {
         '0 0 0' => 'OK',
@@ -285,6 +285,7 @@ sub ValidateRaw($$$)
 {
     my ($self, $tag, $val) = @_;
     my $tagInfo = $$self{TAG_INFO}{$tag};
+    my $wrn;
 
     # evaluate Validate code if specified
     if ($$tagInfo{Validate}) {
@@ -304,10 +305,12 @@ sub ValidateRaw($$$)
         ($$tagInfo{Table} eq \%Image::ExifTool::Exif::Main and $exifSpec{$$tagInfo{TagID}})))
     {
         my $prt = $self->GetValue($tag, 'PrintConv');
-        if ($prt and $prt =~ /^Unknown \(/) {
-            my $name = $$self{DIR_NAME} . ':' . Image::ExifTool::GetTagName($tag);
-            $self->Warn("Unknown value for $name", 1);
-        }
+        $wrn = 'Unknown value for' if $prt and $prt =~ /^Unknown \(/;
+    }
+    $wrn = 'Undefined value for' if $val eq 'undef';
+    if ($wrn) {
+        my $name = $$self{DIR_NAME} . ':' . Image::ExifTool::GetTagName($tag);
+        $self->Warn("$wrn $name", 1);
     }
 }
 
@@ -412,8 +415,20 @@ sub ValidateExif($$$$$$$$)
                 $et->Warn(sprintf('Non-standard %s tag 0x%.4x %s', $ifd, $tag, $$ti{Name}), 1);
             }
         }
-        if ($$ti{Count} and $$ti{Count} > 0 and $count != $$ti{Count}) {
-            $et->Warn(sprintf('Non-standard count (%d) for %s 0x%.4x %s', $count, $ifd, $tag, $$ti{Name}));
+        # change expected count from read Format to Writable size
+        my $tiCount = $$ti{Count};
+        if ($tiCount) {
+            if ($$ti{Format} and $$ti{Writable} and
+                $Image::ExifTool::Exif::formatNumber{$$ti{Format}} and
+                $Image::ExifTool::Exif::formatNumber{$$ti{Writable}})
+            {
+                my $s1 = $Image::ExifTool::Exif::formatSize[$Image::ExifTool::Exif::formatNumber{$$ti{Format}}];
+                my $s2 = $Image::ExifTool::Exif::formatSize[$Image::ExifTool::Exif::formatNumber{$$ti{Writable}}];
+                $tiCount = int($tiCount * $s1 / $s2);
+            }
+            if ($tiCount > 0 and $count != $tiCount) {
+                $et->Warn(sprintf('Non-standard count (%d) for %s 0x%.4x %s', $count, $ifd, $tag, $$ti{Name}));
+            }
         }
     } elsif (not $otherSpec{$$et{VALUE}{FileType}} or
         (not $otherSpec{$$et{VALUE}{FileType}}{$tag} and not $otherSpec{$$et{VALUE}{FileType}}{All}))
@@ -428,6 +443,7 @@ sub ValidateExif($$$$$$$$)
 #         2) directory name, 3) optional flag for minor warning
 sub ValidateOffsetInfo($$$;$)
 {
+    local $_;
     my ($et, $offsetInfo, $dirName, $minor) = @_;
 
     my $fileSize = $$et{VALUE}{FileSize} or return;
@@ -439,10 +455,14 @@ sub ValidateOffsetInfo($$$;$)
     # (don't test 3FR, RWL or RW2 files)
     return if $$et{TIFF_TYPE} =~ /^(3FR|RWL|RW2)$/;
 
+    Image::ExifTool::Exif::ValidateImageData($et, $offsetInfo, $dirName);
+
+    # loop through all offsets
     while (%$offsetInfo) {
         my ($id1) = sort keys %$offsetInfo;
         my $offsets = $$offsetInfo{$id1};
         delete $$offsetInfo{$id1};
+        next unless ref $offsets eq 'ARRAY';
         my $id2 = $$offsets[0]{OffsetPair};
         unless (defined $id2 and $$offsetInfo{$id2}) {
             unless ($$offsets[0]{NotRealPair} or (defined $id2 and $id2 == -1)) {
@@ -488,7 +508,7 @@ sub FinishValidate($$)
 {
     my ($et, $mkTag) = @_;
 
-    my $fileType = $$et{FILE_TYPE};
+    my $fileType = $$et{FILE_TYPE} || '';
     $fileType = $$et{TIFF_TYPE} if $fileType eq 'TIFF';
 
     if ($validValue{$fileType}) {
@@ -500,6 +520,7 @@ sub FinishValidate($$)
             my ($key, %val, %info, $minor);
             foreach $key (keys %{$$et{VALUE}}) {
                 next unless $et->GetGroup($key, 1) eq $grp;
+                next if $$et{TAG_EXTRA}{$key} and $$et{TAG_EXTRA}{$key}{G3}; # ignore sub-documents
                 # fill in %val lookup with values based on tag ID
                 my $tag = $$et{TAG_INFO}{$key}{TagID};
                 $val{$tag} = $$et{VALUE}{$key};
@@ -519,7 +540,7 @@ sub FinishValidate($$)
                     } elsif ($result eq '') {
                         $pre = defined $val ? 'Invalid value for' : "Missing required $fileType";
                     } else {
-                        next if $result == '1';
+                        next if $result eq '1';
                         $pre = $result;
                     }
                 } else {
@@ -557,6 +578,9 @@ sub FinishValidate($$)
             }
         }
     }
+    # issue warning if FastScan option used
+    $et->Warn('Validation incomplete because FastScan option used') if $et->Options('FastScan');
+
     # generate Validate tag if necessary
     if ($mkTag) {
         my (@num, $key);
@@ -589,7 +613,7 @@ ExifTool Validate option is enabled.
 
 =head1 AUTHOR
 
-Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
